@@ -1,4 +1,4 @@
-"""jc - JSON Convert `cksum` command output parser
+r"""jc - JSON Convert `cksum` command output parser
 
 This parser works with the following checksum calculation utilities:
 - `sum`
@@ -8,7 +8,7 @@ Usage (cli):
 
     $ cksum file.txt | jc --cksum
 
-    or
+or
 
     $ jc cksum file.txt
 
@@ -60,6 +60,7 @@ class info():
     author_email = 'kellyjonbrazil@gmail.com'
     compatible = ['linux', 'darwin', 'cygwin', 'aix', 'freebsd']
     magic_commands = ['cksum', 'sum']
+    tags = ['command']
 
 
 __version__ = info.version
