@@ -1,4 +1,4 @@
-"""jc - JSON Convert `iw dev <device> scan` command output parser
+r"""jc - JSON Convert `iw dev <device> scan` command output parser
 
 This parser is considered beta quality. Not all fields are parsed and there
 are not enough samples to test.
@@ -7,7 +7,7 @@ Usage (cli):
 
     $ iw dev wlan0 scan | jc --iw-scan
 
-    or
+or
 
     $ jc iw dev wlan0 scan
 
@@ -122,13 +122,14 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '0.7'
+    version = '0.75'
     description = '`iw dev [device] scan` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     details = 'Enhancements by Philipp Schmitt (https://pschmitt.dev/)'
     compatible = ['linux']
     magic_commands = ['iw dev']
+    tags = ['command']
 
 
 __version__ = info.version
@@ -180,7 +181,7 @@ def _post_parse(data):
         ssid = {k: v for k, v in ssid.items() if v}
         cleandata.append(ssid)
 
-    # remove asterisks from begining of values
+    # remove asterisks from beginning of values
     for ssid in cleandata:
         for key in ssid:
             if ssid[key].startswith('*'):
@@ -297,6 +298,7 @@ def parse(data, raw=False, quiet=False):
 
     raw_output = []
     section = {}
+    header = ''
 
     if jc.utils.has_data(data):
 
@@ -322,7 +324,9 @@ def parse(data, raw=False, quiet=False):
                     split_line[0] = split_line[0].lower().replace('*', '').replace('(', '')\
                                                  .replace(')', '').replace(',', '').replace('-', '_')\
                                                  .strip().replace(' ', '_')
-                    section[split_line[0]] = split_line[1].strip()
+                    if split_line[1] == '':
+                        header = split_line[0] + '_'
+                    section[header + split_line[0]] = split_line[1].strip()
 
                 continue
 
