@@ -1,4 +1,4 @@
-"""jc - JSON Convert `/etc/passwd` file Parser
+r"""jc - JSON Convert `/etc/passwd` file Parser
 
 Usage (cli):
 
@@ -99,6 +99,7 @@ class info():
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     compatible = ['linux', 'darwin', 'aix', 'freebsd']
+    tags = ['file']
 
 
 __version__ = info.version
