@@ -1,4 +1,4 @@
-"""jc - JSON Convert `/etc/shadow` file parser
+r"""jc - JSON Convert `/etc/shadow` file parser
 
 Usage (cli):
 
@@ -9,11 +9,6 @@ Usage (module):
     import jc
     result = jc.parse('shadow', shadow_file_output)
 
-    or
-
-    import jc.parsers.shadow
-    result = jc.parsers.shadow.parse(shadow_file_output)
-
 Schema:
 
     [
@@ -106,11 +101,12 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.4'
+    version = '1.5'
     description = '`/etc/shadow` file parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     compatible = ['linux', 'darwin', 'aix', 'freebsd']
+    tags = ['file']
 
 
 __version__ = info.version
@@ -128,8 +124,9 @@ def _process(proc_data):
 
         List of Dictionaries. Structured data to conform to the schema.
     """
+    int_list = {'last_changed', 'minimum', 'maximum', 'warn', 'inactive', 'expire'}
+
     for entry in proc_data:
-        int_list = ['last_changed', 'minimum', 'maximum', 'warn', 'inactive', 'expire']
         for key in entry:
             if key in int_list:
                 entry[key] = jc.utils.convert_to_int(entry[key])
