@@ -1,4 +1,4 @@
-"""jc - JSON Convert `stat` command output streaming parser
+r"""jc - JSON Convert `stat` command output streaming parser
 
 > This streaming parser outputs JSON Lines (cli) or returns an Iterable of
 > Dictionaries (module)
@@ -77,23 +77,26 @@ import jc.utils
 from jc.streaming import (
     add_jc_meta, streaming_input_type_check, streaming_line_input_type_check, raise_or_yield
 )
+from typing import Dict, Iterable
+from jc.jc_types import JSONDictType, StreamingOutputType
 from jc.exceptions import ParseError
 
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.0'
+    version = '1.3'
     description = '`stat` command streaming parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     compatible = ['linux', 'darwin', 'freebsd']
+    tags = ['command']
     streaming = True
 
 
 __version__ = info.version
 
 
-def _process(proc_data):
+def _process(proc_data: JSONDictType) -> JSONDictType:
     """
     Final processing to conform to the schema.
 
@@ -105,27 +108,36 @@ def _process(proc_data):
 
         Dictionary. Structured data to conform to the schema.
     """
-    int_list = ['size', 'blocks', 'io_blocks', 'inode', 'links', 'uid', 'gid',
-                'unix_device', 'rdev', 'block_size']
-    for key in proc_data:
+    int_list: set[str] = {'size', 'blocks', 'io_blocks', 'inode', 'links', 'uid', 'gid',
+                'unix_device', 'rdev', 'block_size'}
+
+    null_list: set[str] = {'access_time', 'modify_time', 'change_time', 'birth_time'}
+
+    for key in proc_data.copy():
         if key in int_list:
             proc_data[key] = jc.utils.convert_to_int(proc_data[key])
 
-    # turn - into null for time fields and add calculated timestamp fields
-    null_list = ['access_time', 'modify_time', 'change_time', 'birth_time']
-    for key in null_list:
-        if key in proc_data:
+        # turn - into null for time fields and add calculated timestamp fields
+        if key in null_list:
             if proc_data[key] == '-':
                 proc_data[key] = None
-            ts = jc.utils.timestamp(proc_data[key], format_hint=(7100, 7200))
-            proc_data[key + '_epoch'] = ts.naive
-            proc_data[key + '_epoch_utc'] = ts.utc
+
+            ts_string = proc_data[key]
+            if isinstance(ts_string, str) or ts_string is None:
+                ts = jc.utils.timestamp(ts_string, format_hint=(7100, 7200))
+                proc_data[key + '_epoch'] = ts.naive
+                proc_data[key + '_epoch_utc'] = ts.utc
 
     return proc_data
 
 
 @add_jc_meta
-def parse(data, raw=False, quiet=False, ignore_exceptions=False):
+def parse(
+    data: Iterable[str],
+    raw: bool = False,
+    quiet: bool = False,
+    ignore_exceptions: bool = False
+) -> StreamingOutputType:
     """
     Main text parsing generator function. Returns an iterable object.
 
@@ -145,7 +157,7 @@ def parse(data, raw=False, quiet=False, ignore_exceptions=False):
     jc.utils.compatibility(__name__, info.compatible, quiet)
     streaming_input_type_check(data)
 
-    output_line = {}
+    output_line: Dict = {}
     os_type = ''
 
     for line in data:
@@ -154,7 +166,7 @@ def parse(data, raw=False, quiet=False, ignore_exceptions=False):
             line = line.rstrip()
 
             # ignore blank lines
-            if line == '':
+            if not line.strip():
                 continue
 
             # linux output
