@@ -153,7 +153,7 @@ from jc.parsers.universal import sparse_table_parse as parse_table
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.1'
+    version = '1.2'
     description = '`top -b` command streaming parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -409,7 +409,7 @@ def parse(
                     idx += 1
 
                 uptime_str = line[6:]
-                output_line.update(parse_uptime(uptime_str, raw=True))
+                output_line.update(parse_uptime(uptime_str, raw=True, quiet=True))
                 continue
 
             if line.startswith('Tasks:'):
