@@ -42,6 +42,9 @@ class MyTests(unittest.TestCase):
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/centos-8/arp-a.out'), 'r', encoding='utf-8') as f:
         centos8_arp_a = f.read()
 
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/aix-7.1/arp-a.out'), 'r', encoding='utf-8') as f:
+        aix_7_1_arp_a = f.read()
+
     # output
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/centos-7.7/arp.json'), 'r', encoding='utf-8') as f:
         centos_7_7_arp_json = json.loads(f.read())
@@ -76,6 +79,9 @@ class MyTests(unittest.TestCase):
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/centos-8/arp-a.json'), 'r', encoding='utf-8') as f:
         centos8_arp_a_json = json.loads(f.read())
 
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/aix-7.1/arp-a.json'), 'r', encoding='utf-8') as f:
+        aix_7_1_arp_a_json = json.loads(f.read())
+
     def test_arp_nodata(self):
         """
         Test 'arp' with no data
@@ -148,6 +154,13 @@ class MyTests(unittest.TestCase):
         """
         self.assertEqual(jc.parsers.arp.parse(self.centos8_arp_a, quiet=True), self.centos8_arp_a_json)
 
+    def test_arp_a_aix_7_1(self):
+        """
+        Test 'arp -a' on AIX 7.1 with incomplete hw addresses and permanent ARP
+        entries
+        """
+        self.assertEqual(jc.parsers.arp.parse(self.aix_7_1_arp_a, quiet=True), self.aix_7_1_arp_a_json)
+
 
 if __name__ == '__main__':
     unittest.main()
