@@ -1,6 +1,9 @@
 import unittest
-
+import os
+import sys
+sys.path.append(os.getcwd())
 from tests import utils_for_test as test_utils
+sys.path.pop()
 
 
 class MyTests(unittest.TestCase):
