@@ -50,7 +50,10 @@ class MyTests(unittest.TestCase):
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/centos-7.7/ping-ip-O-unparsedlines.out'), 'r', encoding='utf-8') as f:
         centos_7_7_ping_ip_O_unparsedlines = f.read()
 
-    # ubuntu
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/centos-7.7/ping-missing-hostname.out'), 'r', encoding='utf-8') as f:
+        centos_7_7_ping_missing_hostname = f.read()
+
+    # ubuntu 18.4
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-18.04/ping-ip-O.out'), 'r', encoding='utf-8') as f:
         ubuntu_18_4_ping_ip_O = f.read()
 
@@ -78,6 +81,22 @@ class MyTests(unittest.TestCase):
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-18.04/ping6-hostname-O-D-p-s.out'), 'r', encoding='utf-8') as f:
         ubuntu_18_4_ping6_hostname_O_D_p_s = f.read()
 
+    # ubuntu 22.4
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-22.04/ping-dest-unreachable.out'), 'r', encoding='utf-8') as f:
+        ubuntu_22_4_ping_dest_unreachable = f.read()
+
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-22.04/ping-ip-source-ip.out'), 'r', encoding='utf-8') as f:
+        ubuntu_22_4_ping_ip_source_ip = f.read()
+
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-22.04/ping-hostname-source-ip.out'), 'r', encoding='utf-8') as f:
+        ubuntu_22_4_ping_hostname_source_ip = f.read()
+
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-22.04/ping6-ip-source-ip.out'), 'r', encoding='utf-8') as f:
+        ubuntu_22_4_ping6_ip_source_ip = f.read()
+
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-22.04/ping6-hostname-source-ip.out'), 'r', encoding='utf-8') as f:
+        ubuntu_22_4_ping6_hostname_source_ip = f.read()
+
     # fedora
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/fedora32/ping-ip-O.out'), 'r', encoding='utf-8') as f:
         fedora32_ping_ip_O = f.read()
@@ -251,7 +270,10 @@ class MyTests(unittest.TestCase):
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/centos-7.7/ping-ip-O-unparsedlines.json'), 'r', encoding='utf-8') as f:
         centos_7_7_ping_ip_O_unparsedlines_json = json.loads(f.read())
 
-    # ubunutu
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/centos-7.7/ping-missing-hostname.json'), 'r', encoding='utf-8') as f:
+        centos_7_7_ping_missing_hostname_json = json.loads(f.read())
+
+    # ubunutu 18.4
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-18.04/ping-ip-O.json'), 'r', encoding='utf-8') as f:
         ubuntu_18_4_ping_ip_O_json = json.loads(f.read())
 
@@ -279,6 +301,22 @@ class MyTests(unittest.TestCase):
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-18.04/ping6-hostname-O-D-p-s.json'), 'r', encoding='utf-8') as f:
         ubuntu_18_4_ping6_hostname_O_D_p_s_json = json.loads(f.read())
 
+    # ubuntu 22.4
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-22.04/ping-dest-unreachable.json'), 'r', encoding='utf-8') as f:
+        ubuntu_22_4_ping_dest_unreachable_json = json.loads(f.read())
+
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-22.04/ping-ip-source-ip.json'), 'r', encoding='utf-8') as f:
+        ubuntu_22_4_ping_ip_source_ip_json = json.loads(f.read())
+
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-22.04/ping-hostname-source-ip.json'), 'r', encoding='utf-8') as f:
+        ubuntu_22_4_ping_hostname_source_ip_json = json.loads(f.read())
+
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-22.04/ping6-ip-source-ip.json'), 'r', encoding='utf-8') as f:
+        ubuntu_22_4_ping6_ip_source_ip_json = json.loads(f.read())
+
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/ubuntu-22.04/ping6-hostname-source-ip.json'), 'r', encoding='utf-8') as f:
+        ubuntu_22_4_ping6_hostname_source_ip_json = json.loads(f.read())
+
     # fedora
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/fedora32/ping-ip-O.json'), 'r', encoding='utf-8') as f:
         fedora32_ping_ip_O_json = json.loads(f.read())
@@ -549,6 +587,36 @@ class MyTests(unittest.TestCase):
         """
         self.assertEqual(jc.parsers.ping.parse(self.ubuntu_18_4_ping6_hostname_O_D_p_s, quiet=True), self.ubuntu_18_4_ping6_hostname_O_D_p_s_json)
 
+    def test_ping_dest_unreachable_ubuntu_22_4(self):
+        """
+        Test 'ping' on Ubuntu 22.4 with destination unreachable message
+        """
+        self.assertEqual(jc.parsers.ping.parse(self.ubuntu_22_4_ping_dest_unreachable, quiet=True), self.ubuntu_22_4_ping_dest_unreachable_json)
+
+    def test_ping_ip_source_ip_ubuntu_22_4(self):
+        """
+        Test 'ping -I <source_ip> <ip>' on Ubuntu 22.4
+        """
+        self.assertEqual(jc.parsers.ping.parse(self.ubuntu_22_4_ping_ip_source_ip, quiet=True), self.ubuntu_22_4_ping_ip_source_ip_json)
+
+    def test_ping_hostname_source_ip_ubuntu_22_4(self):
+        """
+        Test 'ping -I <source_ip> <hostname>' on Ubuntu 22.4
+        """
+        self.assertEqual(jc.parsers.ping.parse(self.ubuntu_22_4_ping_hostname_source_ip, quiet=True), self.ubuntu_22_4_ping_hostname_source_ip_json)
+
+    def test_ping6_ip_source_ip_ubuntu_22_4(self):
+        """
+        Test 'ping6 -I <source_ip> <ip>' on Ubuntu 22.4 with source IP address
+        """
+        self.assertEqual(jc.parsers.ping.parse(self.ubuntu_22_4_ping6_ip_source_ip, quiet=True), self.ubuntu_22_4_ping6_ip_source_ip_json)
+
+    def test_ping6_hostname_source_ip_ubuntu_22_4(self):
+        """
+        Test 'ping6 -I <source_ip> <hostname>' on Ubuntu 22.4 with source IP address
+        """
+        self.assertEqual(jc.parsers.ping.parse(self.ubuntu_22_4_ping6_hostname_source_ip, quiet=True), self.ubuntu_22_4_ping6_hostname_source_ip_json)
+
     def test_ping_ip_O_fedora32(self):
         """
         Test 'ping <ip> -O' on fedora32
@@ -801,6 +869,12 @@ class MyTests(unittest.TestCase):
         """
         self.assertEqual(jc.parsers.ping.parse(self.alpine_linux_3_13_ping_hostname, quiet=True), self.alpine_linux_3_13_ping_hostname_json)
 
+    def test_ping_missing_hostname(self):
+        """
+        Test 'ping' with missing hostname on linux
+        """
+        self.assertEqual(jc.parsers.ping.parse(self.centos_7_7_ping_missing_hostname, quiet=True), self.centos_7_7_ping_missing_hostname_json)
+
 
 if __name__ == '__main__':
     unittest.main()
