@@ -1,6 +1,4 @@
 import os
-import sys
-import time
 import json
 import unittest
 from jc.exceptions import ParseError
@@ -8,11 +6,6 @@ import jc.parsers.stat_s
 
 THIS_DIR = os.path.dirname(os.path.abspath(__file__))
 
-# Set the timezone on POSIX systems. Need to manually set for Windows tests
-if not sys.platform.startswith('win32'):
-    os.environ['TZ'] = 'America/Los_Angeles'
-    time.tzset()
-
 
 # To create streaming output use:
 # $ cat stat.out | jc --stat-s | jello -c > stat-streaming.json
