@@ -15,6 +15,9 @@ class MyTests(unittest.TestCase):
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/osx-10.14.6/zipinfo-multi.out'), 'r', encoding='utf-8') as f:
         osx_10_14_6_zipinfo_multi = f.read()
 
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/rhel-8/zipinfo-space-in-name.out'), 'r', encoding='utf-8') as f:
+        rhel_8_zipinfo_space_in_name = f.read()
+
     # output
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/rhel-8/zipinfo.json'), 'r', encoding='utf-8') as f:
         rhel_8_zipinfo_json = json.loads(f.read())
@@ -22,6 +25,9 @@ class MyTests(unittest.TestCase):
     with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/osx-10.14.6/zipinfo-multi.json'), 'r', encoding='utf-8') as f:
         osx_10_14_6_zipinfo_multi_json = json.loads(f.read())
 
+    with open(os.path.join(THIS_DIR, os.pardir, 'tests/fixtures/rhel-8/zipinfo-space-in-name.json'), 'r', encoding='utf-8') as f:
+        rhel_8_zipinfo_space_in_name_json = json.loads(f.read())
+
 
     def test_zipinfo_nodata(self):
         """
@@ -41,6 +47,12 @@ class MyTests(unittest.TestCase):
         """
         self.assertEqual(jc.parsers.zipinfo.parse(self.osx_10_14_6_zipinfo_multi, quiet=True), self.osx_10_14_6_zipinfo_multi_json)
 
+    def test_zipinfo_rhel_8_space_in_name(self):
+        """
+        Test 'zipinfo' on Red Hat 8 with spaces in the file path
+        """
+        self.assertEqual(jc.parsers.zipinfo.parse(self.rhel_8_zipinfo_space_in_name, quiet=True), self.rhel_8_zipinfo_space_in_name_json)
+
 
 if __name__ == '__main__':
     unittest.main()
